==> activity-center-api-3.5.9-sources.jar: cn/com/duiba/activity/center/api/dto/haggle/HaggleHelpRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.haggle;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: lufeng
 * @Description: 砍价活动帮砍记录dto
 * @Date: Created in 2019/9/23
 */
public class HaggleHelpRecordDto implements Serializable{

    private static final long serialVersionUID = 4648824134917528685L;

    private Long id;

    //砍价活动配置表id
    private Long configId;

    //应用id
    private Long appId;

    //发起砍价表id
    private Long openRecordId;

    //用户id
    private Long consumerId;

    //砍价金额
    private Long money;

    //昵称
    private String nickName;

    //头像
    private String avatar;

    //创建时间
    private Date gmtCreate;

    //修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOpenRecordId() {
        return openRecordId;
    }

    public void setOpenRecordId(Long openRecordId) {
        this.openRecordId = openRecordId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getMoney() {
        return money;
    }

    public void setMoney(Long money) {
        this.money = money;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAvatar() {
        return avatar;
    }

    public void setAvatar(String avatar) {
        this.avatar = avatar;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-3.6.11-20250108.063337-5-sources.jar: cn/com/duiba/activity/center/api/dto/haggle/HaggleHelpRecordDto.java <==
package cn.com.duiba.activity.center.api.dto.haggle;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: lufeng
 * @Description: 砍价活动帮砍记录dto
 * @Date: Created in 2019/9/23
 */
public class HaggleHelpRecordDto implements Serializable{

    private static final long serialVersionUID = 4648824134917528685L;

    private Long id;

    //砍价活动配置表id
    private Long configId;

    //应用id
    private Long appId;

    //发起砍价表id
    private Long openRecordId;

    //用户id
    private Long consumerId;

    //砍价金额
    private Long money;

    //昵称
    private String nickName;

    //头像
    private String avatar;

    /**
     * 当前助力次数
     */
    private Integer helpCount;

    //创建时间
    private Date gmtCreate;

    //修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConfigId() {
        return configId;
    }

    public void setConfigId(Long configId) {
        this.configId = configId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getOpenRecordId() {
        return openRecordId;
    }

    public void setOpenRecordId(Long openRecordId) {
        this.openRecordId = openRecordId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getMoney() {
        return money;
    }

    public void setMoney(Long money) {
        this.money = money;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAvatar() {
        return avatar;
    }

    public void setAvatar(String avatar) {
        this.avatar = avatar;
    }

    public Integer getHelpCount() {
        return helpCount;
    }

    public void setHelpCount(Integer helpCount) {
        this.helpCount = helpCount;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
